@@ -10,10 +10,11 @@ from nltk.tokenize import word_tokenize, sent_tokenize
 from .decorators import cached_property
 from .utils import lowerstrip, strip_punc, PUNCTUATION_REGEX
 from .inflect import singularize as _singularize, pluralize as _pluralize
-from .en import sentiment as _sentiment, tag
+from .en import sentiment as _sentiment
 from .mixins import ComparableMixin
 from .compat import text_type, string_types, unicode
-from .np_extractor import FastNPExtractor
+from .np_extractors import BaseNPExtractor, FastNPExtractor
+from .taggers import BaseTagger, PatternTagger
 
 
 class Word(unicode):
@@ -64,8 +65,8 @@ class WordList(list):
         strings = [text_type(w) for w in self._collection]
         if len(self) > 60:
             return '{cls}({beginning}...{end})'.format(cls=class_name,
-                    beginning=strings[:3],
-                    end=strings[-3:])
+                                                beginning=strings[:3],
+                                                end=strings[-3:])
         else:
             return '{cls}({lst})'.format(cls=class_name, lst=strings)
 
@@ -118,12 +119,17 @@ class BaseBlob(ComparableMixin):
     '''
 
     np_extractor = FastNPExtractor()
+    pos_tagger = PatternTagger()
 
-    def __init__(self, text):
+    def __init__(self, text, np_extractor=None, pos_tagger=None):
         '''Create a blob-like object.
 
         Arguments:
         - text: A string, the text.
+        - np_extractor: An instance of an noun phrase extractor class found in
+            text.np_extractor. Defaults to the FastNPExtractor.
+        - pos_tagger: An instance of a POS tagger found in text.taggers.
+            Defaults to the PatternTagger.
          '''
         if type(text) not in string_types:
             raise TypeError('The `text` argument passed to `__init__(text)` '
@@ -131,6 +137,14 @@ class BaseBlob(ComparableMixin):
         self.raw = text
         self.string = text
         self.stripped = lowerstrip(text)
+        if (np_extractor is not None and
+                not isinstance(np_extractor, BaseNPExtractor)):
+            raise ValueError("np_extractor must be an instance of BaseNPExtractor")
+        self.np_extractor = np_extractor if np_extractor else BaseBlob.np_extractor
+        if (pos_tagger is not None and
+                not isinstance(pos_tagger, BaseTagger)):
+            raise ValueError("pos_tagger must be an instance of BaseTagger")
+        self.pos_tagger = pos_tagger if pos_tagger else BaseBlob.pos_tagger
 
     def _tokenize(self):
         '''Tokenizes the blob into words.'''
@@ -172,10 +186,8 @@ class BaseBlob(ComparableMixin):
                     ('Thursday', 'NNP'), ('morning', 'NN')]
         '''
         return [(Word(word, pos_tag=t), text_type(t))
-                for word, t in tag(self.raw, tokenize=True)
-                if not len(word) == 1
-                    and not PUNCTUATION_REGEX.match(text_type(t))]
-
+                for word, t in self.pos_tagger.tag(self.raw)
+                if not PUNCTUATION_REGEX.match(text_type(t))]
 
     @cached_property
     def word_counts(self):
@@ -214,6 +226,10 @@ class BaseBlob(ComparableMixin):
         or str(my_blob).'''
         return self.raw
 
+    def __unicode__(self):
+        '''Returns the unicode representation of the blob.'''
+        return unicode(self.raw)
+
     def __iter__(self):
         '''Makes the object iterable as if it were a string,
         iterating through the raw string's characters.
@@ -444,4 +460,4 @@ class Sentence(BaseBlob):
             'stripped': self.stripped,
             'noun_phrases': self.noun_phrases,
             'sentiment': self.sentiment,
-            }
+        }
